@@ -3,7 +3,7 @@
 {
   library.dynam("geoR", package = pkg, lib.loc = lib)  
   cat("\n")
-  cat("------------------------------------------------\n")
+  cat("-------------------------------------------------\n")
   if(is.R()){
     cat(package.description("geoR", lib = lib, field="Title"))
     cat("\n")
@@ -14,7 +14,7 @@
     cat("geoS: a package for geostatistical analysis in R\n")
     cat("geoS is now loaded\n")
   }
-  cat("------------------------------------------------\n")
+  cat("-------------------------------------------------\n")
   cat("\n")
   return(invisible(0))
 }
